@@ -55,14 +55,14 @@ except ImportError:
 ########################################
 
 sqlStringReplace = [
+    ("'", "''"),
     ('\\', '\\\\'),
-    ("'", "\\'"),
     ('\000', '\\0'),
     ('\b', '\\b'),
     ('\n', '\\n'),
     ('\r', '\\r'),
     ('\t', '\\t'),
-    ]
+]
 
 def isoStr(val):
     """
@@ -204,14 +204,14 @@ if hasattr(time, 'struct_time'):
 
 if datetime:
     def DateTimeConverter(value, db):
-        return "'%4d-%02d-%02d %02d:%02d:%02d'" % (
+        return "'%04d-%02d-%02d %02d:%02d:%02d'" % (
             value.year, value.month, value.day,
             value.hour, value.minute, value.second)
 
     registerConverter(datetime.datetime, DateTimeConverter)
 
     def DateConverter(value, db):
-        return "'%4d-%02d-%02d'" % (value.year, value.month, value.day)
+        return "'%04d-%02d-%02d'" % (value.year, value.month, value.day)
 
     registerConverter(datetime.date, DateConverter)
 
@@ -222,7 +222,8 @@ if datetime:
 
 if Decimal:
     def DecimalConverter(value, db):
-        return value.to_eng_string()
+        # See http://mail.python.org/pipermail/python-dev/2008-March/078189.html
+        return str(value.to_eng_string()) # Convert to str to work around a bug in Python 2.5.2
 
     registerConverter(Decimal, DecimalConverter)
 
